@@ -1,7 +1,7 @@
 package AnyMerchant::Gateway;
 use Moo::Role;
 
-requires qw(authorize capture charge refund void);
+requires qw(debit authorize capture credit void);
 
 
 1;
@@ -16,7 +16,7 @@ AnyMerchant::Gateway
 
 =head1 VERSION
 
-version 0.0001
+version 0.0002
 
 =head1 DESCRIPTION
 
@@ -24,24 +24,40 @@ This role defines the interface for all C<AnyMerchant::Gateway::* classes>.
 
 =head1 METHODS
 
+The param C<$amount> is an integer representing cents.
+An amount of 1000 corresponds to $10.00.
+
+The param C<$source> refers to either a credit card or a bank account.
+It may be a proper object or a hashref.
+
+=head2 debit
+
+    debit($amount, $source, %params)
+
+Charge a credit card or debit a bank account.
+
 =head2 authorize
 
+    authorize($amount, $source, %params)
+
 Authorize a transaction.
 
 =head2 capture
 
+    capture($amount, $id, %params)
+
 Capture an authorized transaction.
 
-=head2 debit
+=head2 credit
 
-Debit a credit card or bank account.
+    credit($amount, $target, %params)
 
-=head2 refund
-
-Refund a transaction.
+Credit account.
 
 =head2 void
 
+    void($id, %params)
+
 Void a transaction.
 
 =head1 AUTHOR
